@@ -34,6 +34,29 @@
  * 
  * ***** END LICENSE BLOCK ***** */
 
+function getAppVersion ()
+{
+  var versionString = null;
+  try {
+    versionString = Components.classes["@mozilla.org/fuel/application;1"].getService(Components.interfaces.extIApplication).version;
+  } catch (e) {
+  }
+
+  if (versionString == null)
+    return NULL;
+
+  if (String_startsWith (versionString, "3.0"))
+    versionString = "3.0";
+  else if (String_startsWith (versionString, "3.5"))
+    versionString = "3.5";
+  else if (String_startsWith (versionString, "3.6"))
+    versionString = "3.6";
+  else if (String_startsWith (versionString, "3.7"))
+    versionString = "3.7";
+
+  return versionString;
+}
+
 var ubufox = {
   onAddonsLoad: function () {
     this.isffox3 = false;
@@ -133,19 +156,26 @@ function ubufoxReportBug(event) {
 
   procUtil.init(executable);
 
-  var args = new Array("-p", "firefox-3.0" );
+  var args = null;
+  if (getAppVersion())
+    args = new Array("-p", "firefox-" + getAppVersion());
+  else
+    args = new Array("-p", "firefox" );
+
   var res = procUtil.run(false, args, args.length);
 }
 
 
 function ubufoxGetHelpOnline(event)
 {
-  openUILink("https://launchpad.net/distros/ubuntu/jaunty/+sources/firefox-3.0/+gethelp", event, false, true);
+  var getHelpUrl = "https://launchpad.net/distros/ubuntu/karmic/+sources/firefox-" + getAppVersion () + "/+gethelp";
+  openUILink(getHelpUrl, event, false, true);
 }
 
 function ubufoxHelpTranslateLaunchpad(event)
 {
-  openUILink("https://launchpad.net/distros/ubuntu/jaunty/+sources/firefox-3.0/+translate", event, false, true);
+  var translateUrl = "https://launchpad.net/distros/ubuntu/karmic/+sources/firefox-" + getAppVersion () + "/+translate";
+  openUILink(translateUrl, event, false, true);
 }
 
 function ubufoxCheckExecutable(filename)
