@@ -130,10 +130,16 @@ if (!filehintNameMap)
 function showContentList(){
   var contentName;
   if(!filteredMimeTypes) {
+    let showSelectedRadio = document.getElementById ("radioShowSelectedPlugins");
+    let showAllRadio = document.getElementById ("radioShowAllPlugins");
+    let containingRadio = document.getElementById ("radioShowParent");
     if(usedMimeTypes.length <= 0)
       filteredMimeTypes = allHandledMimeTypes;
     else
       filteredMimeTypes = usedMimeTypes;
+
+    // select the right initial choice
+    containingRadio.selectedItem = usedMimeTypes.length <= 0 ? showAllRadio : showSelectedRadio;
   }
   var _list = document.getElementById("pluginsList");   
   while (_list.hasChildNodes())
